# {{ ansible_managed }}

[DEFAULT]

# Base container image distribution.
base={{ kolla_base_distro }}

# Method of OpenStack install. Valid options are [ binary, source ]
install_type={{ kolla_install_type }}

# Docker namespace to use for Kolla images.
namespace={{ kolla_docker_namespace }}

# Use host networking by default, in line with Kolla Ansible's default Docker
# engine configuration.
network_mode=host

# Docker image tag to apply.
tag={{ kolla_tag }}

# Path to a file containing template overrides.
template_override={{ kolla_build_config_path }}/template-override.j2

{% for source_name, source_def in kolla_sources.items() %}
[{{ source_name }}]
{% if source_def.type is defined %}
# Type of source for {{ source_name }}.
type = {{ source_def.type }}
{% endif %}
{% if source_def.location is defined %}
# Location of source for {{ source_name }}.
location = {{ source_def.location }}
{% endif %}
{% if source_def.reference is defined %}
# Reference of source for {{ source_name }}.
reference = {{ source_def.reference }}
{% endif %}

{% endfor %}

{% if kolla_build_extra_config is defined %}
#######################
# Extra configuration
#######################

{{ kolla_build_extra_config }}
{% endif %}
